/*
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores
 * CA 94065 USA or visit www.oracle.com if you need additional information or
 * have any questions.
 */
package com.sun.lwuit.impl.android;

import android.content.Context;
import android.view.inputmethod.InputMethodManager;
import com.sun.lwuit.impl.VirtualKeyboardInterface;

/**
 *
 */
public class AndroidKeyboard implements VirtualKeyboardInterface {

    private boolean keyboardShowing;
    private Context context;
    private AndroidView myView;

    public AndroidKeyboard(Context context, AndroidView myView) {
        this.context = context;
        this.myView = myView;
    }

    public String getVirtualKeyboardName() {
        return "Android Keyboard";
    }

    public void showKeyboard(boolean show) {
        if (keyboardShowing != show) {
            InputMethodManager manager = (InputMethodManager) context.getSystemService(Context.INPUT_METHOD_SERVICE);
            manager.restartInput(myView);
            manager.toggleSoftInputFromWindow(myView.getWindowToken(), 0, 0);
            this.keyboardShowing = show;

            /*
             * suggested alternative from the forums, could not test it yet.
            InputMethodManager manager = (InputMethodManager) context.getSystemService(Context.INPUT_METHOD_SERVICE);
            if (show) {
                manager.showSoftInput(myView, 0);
            } else {
                manager.hideSoftInputFromWindow(myView.getWindowToken(), 0);
            }
            this.keyboardShowing = show;
             *
             */
        }
    }

    public boolean isVirtualKeyboardShowing() {
        return keyboardShowing;
    }
}
